California Secretary of State - CalAccess - Campaign Finance

Advanced Search
| Candidates & Elected Officials
Propositions & Ballot Measures
Committees, Parties, Major Donors & Slate Mailers
Daily/Late/ Special Filings
| Campaign Finance: PROPOSITION 009 - CRIMINAL JUSTICE SYSTEM. VICTIMS' RIGHTS. PAROLE. INITIATIVE CONSTITUTIONAL AMENDMENT AND STATUTE. View Information: General Information Late Independent Expenditures Affecting This Measure
How much money is being raised and spent to pass or defeat California propositions and ballot measures, and what are the sources of the money? Check here to follow the money trail.
Committees formed to support or oppose the ballot measure.
COMMITTEE ID | COMMITTEE NAME | COMMITTEE POSITION
1303492 | MARSY'S LAW: JUSTICE FOR CRIME VICTIMS, YES ON PROP. 9 | SUPPORT
COMMITTEE ID | COMMITTEE NAME | COMMITTEE POSITION
1312996 | CAMPAIGN AGAINST PROPOSITIONS 4, 6, 8, 9, & FOR PROPOSITION 5 CALIFORNIANS FOR JUSTICE EDUCATION FUND | OPPOSE
COMMITTEE ID | COMMITTEE NAME | COMMITTEE POSITION
1308244 | NO ON PROPS 6 & 9, A COMMITTEE FOR FISCAL RESPONSIBILITY WITH TEACHERS, FIREFIGHTERS, SERVICE EMPLOYEES AND CIVIL RIGHTS GROUPS | OPPOSE
COMMITTEE ID | COMMITTEE NAME | COMMITTEE POSITION
1309869 | YES ON PROP 9 - MARSY'S LAW: THE 2008 CRIME VICTIMS BILL OF RIGHTS ACT | SUPPORT